Fire class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
add({required String collectionName, required Map<String, dynamic> value})
→ Future<String?>
-
-
delete({required String collectionName})
→ dynamic
-
-
deleteAll({required String collectionName})
→ dynamic
-
-
get({required String collectionName, List<FireWhereField>? where, FireOrder? orderBy})
→ dynamic
-
-
getRef({required String collectionName, List<FireWhereField>? where, FireOrder? orderBy})
→ dynamic
-
-
initialize({required String apiKey, required String projectId, required String appId, required String messagingSenderId, bool useGoogleServicesJson = false})
→ Future
-
-
register({required String email, required String password})
→ Future<bool>
-
-
resetPassword({required String email})
→ Future
-
-
set({required String collectionName, required Map<String, dynamic> value})
→ dynamic
-
-
signIn({required String email, required String password})
→ Future<bool>
-
-
signInAnonymously()
→ Future<bool>
-
-
signInByGoogle()
→ Future<bool>
-
-
signOut()
→ Future
-
-
snapshot({required String collectionName, List<FireWhereField>? where, FireOrder? orderBy})
→ dynamic
-
-
timestamp()
→ dynamic
-
-
update({required String collectionName, required Map<String, dynamic> value})
→ dynamic
-