GlobalUser class

Constructors

GlobalUser({required String uid, String? displayName, String? photoURL, String? phoneNumber, String? email})

Properties

displayName String?
final
email String?
final
hashCode int
The hash code for this object.
no setterinherited
phoneNumber String?
final
photoURL String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uid String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited