FireDartFirestore class

Constructors

FireDartFirestore(String projectId, {String? databaseId, FireDartFirebaseAuth? auth})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

collection(String path) FireDartCollectionReference
document(String path) FireDartDocumentReference
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reference(String path) FireDartReference
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FireDartFirestore
no setter

Static Methods

initialize(String projectId, {String? databaseId}) FireDartFirestore