FireDartFirestoreGatewayStreamCache class
Constructors
- FireDartFirestoreGatewayStreamCache({void onDone(String userInfo)?, required String userInfo, dynamic onError(Object e)?})
Properties
-
documentMap
→ Map<
String, FireDartDocument> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- onDone ↔ void Function(String userInfo)?
-
getter/setter pair
- onError ↔ void Function(Object e)
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
ListenResponse> -
no setter
- userInfo ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setListenRequest(
ListenRequest request, FirestoreClient client, String database) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited